#
# spec file for package mate-indicator-applet
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.26

Name:           mate-indicator-applet
Version:        1.26.0
Release:        bp156.3.7
Summary:        Information from applications consistently on the panel
License:        GPL-3.0-only AND LGPL-3.0-only
Group:          System/GUI/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ayatana-indicator3-0.4)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libayatana-ido3-0.4)
BuildRequires:  pkgconfig(libmatepanelapplet-4.0) >= %{_version}
BuildRequires:  pkgconfig(mate-settings-daemon) >= %{_version}
BuildRequires:  pkgconfig(x11)

%description
The indicator applet exposes Ayatana Indicators in the MATE Panel.
Ayatana Indicators are an initiative by Canonical to provide crisp
and clean system and application status indication. They take the
form of an icon and associated menu, displayed (usually) in the
desktop panel. Existing indicators include the Message Menu,
Battery Menu and Sound menu.

%package -n mate-applet-indicator
Summary:        Information from applications consistently on the panel
Group:          System/GUI/Other
Recommends:     mate-applet-indicator-lang
Provides:       ayatana-indicator-renderer
# mate-indicator-applet was last used in openSUSE Leap 42.1.
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Obsoletes:      %{name}-lang < %{version}
%glib2_gsettings_schema_requires

%description -n mate-applet-indicator
The indicator applet exposes Ayatana Indicators in the MATE Panel.
Ayatana Indicators are an initiative by Canonical to provide crisp
and clean system and application status indication. They take the
form of an icon and associated menu, displayed (usually) in the
desktop panel. Existing indicators include the Message Menu,
Battery Menu and Sound menu.

%lang_package -n mate-applet-indicator

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static                    \
  --disable-scrollkeeper              \
  --with-ayatana-indicators           \
  --libexecdir=%{_libexecdir}/%{name}
%make_build

%install
%make_install
%find_lang %{name}

%files -n mate-applet-indicator
%license COPYING COPYING.LGPL
%doc AUTHORS NEWS README
%{_libexecdir}/%{name}/
%{_datadir}/dbus-1/services/org.mate.panel.applet.IndicatorApplet*.service
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/org.mate.applets.Indicator.mate-panel-applet
%{_datadir}/mate-panel/applets/org.mate.applets.IndicatorAppmenu.mate-panel-applet
%{_datadir}/mate-panel/applets/org.mate.applets.IndicatorComplete.mate-panel-applet

%files -n mate-applet-indicator-lang -f %{name}.lang

%changelog
* Sat Aug 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * applet-main: Replace GtkStock icon
  * Update copyright to 2021
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.22.0):
  * Resize indicator icons to fit panel.
  * Rename data/org*mate-panel-applet.desktop.in.in files.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
- Remove mate-indicator-applet-gtk-3.20.patch.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * tomboykeybinder: Avoid gdk_error_trap_push/pop and gdk_flush.
  * Migrate the language list to po/LINGUAS file
  * Disable deprecation warnings for distcheck.
  * tomboykeybinder: Avoid deprecated gdk_keymap_get_default.
  * Update translations.
* Mon Jun 18 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Wed Mar 21 2018 sor.alexei@meowr.ru
- Switch to using Ayatana Indicators.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22.
  * Support building against Ayatana Indicators.
- Add mate-indicator-applet-gtk-3.20.patch: Restore GTK+ 3.20
  support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Add our copyright to the about dialogue.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Show new style indicator support status in summary.
  * Build: Require mate-panel >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Build: Fix checking for the new style indicators support.
  * Update translations.
* Mon Jun 20 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * GTK+3: Add support for new style indicators (that load from
    directory /usr/share/unity/indicators/.
    It requires libindicator >= 12.10 and libido >= 13.10. Support
    for older versions of libindicator is left intact.
  * GTK+3: Allow indicators to receive mouse scroll event.
- Rename package to mate-applet-indicator.
- Provide indicator-renderer-gtk2.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * GTK+3: Fix several deprecations.
  * Update translations.
  * Fix Changelog generation.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Allow volume change with mouse scroll over sound indicator's
    icon.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Bug fixes.
* Wed May  6 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.0):
  * Drop indicator-0.3 support.
- Spec cleanup.
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Add GTK3 support
  + Fixed conflicts with GNOME's indicator-applet
- Fix version requirements
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + Bugs fix release
* Thu Apr  4 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + no changes since 1.5.1
* Mon Mar 25 2013 p.drouand@gmail.com
- Update to version 1.5.1
  * include directly directly glib.h
- Remove only-include-glib.h.patch; merged on upstream release
* Wed Feb 27 2013 p.drouand@gmail.com
- Initial release
